---
feature_story: FS_36_17_84_44
feature_title: check_env script
feature_status: TEST
---

# Purpose

Shell environment is too flexible in config to rely on it blindly
(e.g. it allows aliases to override any command).

There should be a script to check automatically and report any issues with the setup (to support user easily).

The script is supposed to provide single place to perform multi-level verification.

This script may overlap with functions from FS_85_33_46_53 `bootstrap_env`.

See also FS_86_73_43_45 server control scripts.

# Idea

The set of checks to be performed should be open for extension by the target project.

It can start as Bash code by checking:
*   Python version
*   `venv` existence
*   `argrelay` package existence
Then, it can continue as Python code by checking anything else.

Guidelines:
*   Bash part executes (preferably) things until it is confirmed that Python `venv` is ready to execute Python part.
*   As much as possible, checks should be implemented in Python part (as it is easier to test this logic).

# Implementation

Entry point:
*   It is started (both Bash and Python parts) by single script `@/exe/check_env.bash`.

Config files:
*   Plugins for Bash part are configured by `@/conf/check_env.conf.bash`.
*   Plugins for Bash part are simply scripts executed from `@/conf/check_env.conf.bash`
    (hoping that their output has the same expected color scheme and style).
*   Plugins for Python part are configured by `@/conf/check_env.yaml`.
*   Plugins for Python part are the same as any other plugin but extend `PluginCheckEnvAbstract`.

# Plans

Checks:
*   DONE: whether it is run under FS_58_61_77_69 `dev_shell`
*   check whether debug enabled and which debug (p, s, ... etc.).
*   whether `PATH` env var reaches client and server binaries
*   whether completion is configured in shell
*   DONE: `@/conf` locations used
*   any useful missing (or useless existing) settings in `~/.inputrc`
*   DONE: server availability
*   server version and compatibility
*   prints server instance id and whatever we can query to verify its state
*   print plugin list (serialized DAG) with types and activation status
*   verify whether there is any issues between:
    *   client-side plugin config
    *   server-side plugin config
*   any useful `readline` settings set or not
*   DONE: FS_57_36_37_48 (multiple clients) show all registered clients
*   DONE: show all registered commands (FS_57_36_37_48 per client)
*   DONE: print the same line info what `@/exe/dev_shell.bash` prints about version, conf, URL, etc.

What else?

```
# TODO: Connect to server to get:
#       server instance id (UUID),
#       argrelay framework server version,
#       server start time,
#       server setup version,
#       server setup commit id,
#       etc.

# TODO: Check if server is local.
#       Do not check via hostname.
#       Simply check netstat against port number to select pid.
#       Check if pid file exists.
#       Check if pid in pid file matches pid from netstat.
#       Verify if localhost:server_port_number succeeds with the same server instance id.

# TODO: additionally:
#       show latest server log.
```
